#if !defined(AFX_FEATURELIBDIAG_H__29974841_1810_11D3_A5F1_00902712C9AE__INCLUDED_)
#define AFX_FEATURELIBDIAG_H__29974841_1810_11D3_A5F1_00902712C9AE__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// FeatureLibDiag.h : header file
//
#include "ListBoxPro.h"


class CFeatureLibView;
/////////////////////////////////////////////////////////////////////////////
// CFeatureLibDiag dialog

class CFeatureLibDiag : public CDialog
{
// Construction
public:
	void SaveSelectedFeatures(CString str);
	void LoadFeatures(CString fname);
	void SetSelection();
	void InitBackGround();
	void UpdateHLList();
	void ResizeVert(int cy);
	void ResizeHor(int cx);
	void SetView(CFeatureLibView *vwe);
	CFeatureLibView *OwnerView;
	void RefreshList();
	CString MakeDefaultName();
	void SelectUnsed();

	CFeatureLibDiag(CWnd* pParent = NULL);   // standard constructor
// Dialog Data
	//{{AFX_DATA(CFeatureLibDiag)
	enum { IDD = IDD_FEATURELIBDIAG };
	CButton	m_BgdProps;
	CButton	m_delbut;
	CButton	m_addbut;
	CListBoxPro	m_FeatureList;
	//}}AFX_DATA
	int CurSel;
// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CFeatureLibDiag)
	public:
	virtual int DoModal();
	protected:
	virtual void OnOK();
	virtual void OnCancel();
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
	virtual BOOL OnNotify(WPARAM wParam, LPARAM lParam, LRESULT* pResult);
	//}}AFX_VIRTUAL

// Implementation
protected:

	// Generated message map functions
	//{{AFX_MSG(CFeatureLibDiag)
	afx_msg void OnAdd();
	afx_msg void OnDblclkFeaturelist(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg void OnRclickFeaturelist(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg void OnLclickFeaturelist(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg void OnBegindragFeaturelist(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg void OnMouseMove(UINT nFlags, CPoint point);
	afx_msg void OnSelchangeFeaturelist();
	afx_msg void OnKillfocusFeaturelist();
	afx_msg void OnSetfocusFeaturelist();
	afx_msg void OnBackground();
	afx_msg void OnDelete();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_FEATURELIBDIAG_H__29974841_1810_11D3_A5F1_00902712C9AE__INCLUDED_)
